===========================
 cernopendata-pages v1.0.0
===========================

cernopendata-pages v1.0.0 was released on January 19, 2017.

About
-----

Pages for CERN Open Data Portal.

What's new
----------

- Initial public release contains only a home page.

Installation
------------

   $ pip install cernopendata-pages==1.0.0

Happy hacking and thanks for flying cernopendata-pages.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: https://twitter.com/inveniosoftware
|   GitHub: https://github.com/cernopendata/cernopendata-pages
|   URL: http://inveniosoftware.org
